;+
; PROCEDURE:
;   loadproc_template, site = site, $
;                     datatype=datatype, $
;                     trange=trange, $
;                     verbose=verbose, $
;                     downloadonly=downloadonly, $
;                     no_download=no_download
;
; PURPOSE:
;   This is an example showing how to create a load procedure for 
;   CDF or ASCII files.
;
; KEYWORDS:
;   site  : site
;   datatype : datatype
;   trange : (Optional) Time range of interest  (2 element array).
;   /verbose: set to output some useful info
;   /downloadonly: if set, then only download the data, do not load it 
;           into variables.
;   /no_download: use only files which are online locally.
;
; EXAMPLE:
;   thm_init
;   timespan, '1992-1-21'
;   loadproc_mu_rish_ascii
;   tplot, 'rish_mu_uwnd'
;
; Written by Y.-M. Tanaka, March 13, 2018
; Modified by Y.-M. Tanaka, September 5, 2018
;-

pro loadproc_mu_rish_ascii, site=site, datatype=datatype, $
        trange=trange, verbose=verbose, downloadonly=downloadonly, $
	    no_download=no_download

;********************************;
;***** Step1: Set paramters *****;
;********************************;
file_format='ascii'   ; Choose 'cdf' or 'ascii'
url='http://www.rish.kyoto-u.ac.jp/mu/data/data/ver01.0807_1.02/YYYYMM/YYYYMMDD/YYYYMMDD.uwnd.csv'
acknowledgement = 'You can write the data use policy here.' + $
    'This description is displayed when you use this load procedure.'
site_list='sta1'
datatype_list='test'

;===== Split URL =====;
split_url, url=url, remote_data_dir=remote_data_dir, $
    pathname_base=pathname_base, filename_base=filename_base
ipos_local=strpos(remote_data_dir, '://')+3
local_data_dir  = root_data_dir() + $
    strmid(remote_data_dir, ipos_local, strlen(remote_data_dir)-ipos_local)   ; Base local directory
; remote_data_dir='http://www.iugonet.org/data/'
; local_data_dir  = root_data_dir() + 'tmp/'

;===== Keyword check =====;
;----- default -----;
if ~keyword_set(verbose) then verbose=0
if ~keyword_set(downloadonly) then downloadonly=0
if ~keyword_set(no_download) then no_download=0

;----- remote_data_dir -----;
if remote_data_dir eq '' then remote_data_dir=' '

;----- site -----;
if n_elements(site_list) eq 0 then site_list='sta'
site_all = strsplit(site_list, /extract)
if(not keyword_set(site)) then site='all'
site = ssl_check_valid_name(site, site_all, /ignore_case, /include_all)
if site[0] eq '' then return

;----- datatype -----;
if n_elements(datatype_list) eq 0 then datatype_list='dt'
datatype_all=strsplit(datatype_list, /extract)
if(not keyword_set(datatype)) then datatype='all'
datatype=ssl_check_valid_name(datatype, datatype_all, /ignore_case, /include_all)
if datatype[0] eq '' then return

;----- Make date & time string array -----;
ipos=strpos(url, 'hh')
if ipos lt 0 then hres=0 else hres=1
yyyy = file_dailynames(file_format='YYYY', trange=trange, hour_res=hres)
yy = file_dailynames(file_format='yy', trange=trange, hour_res=hres)
mm = file_dailynames(file_format='MM', trange=trange, hour_res=hres)
dd = file_dailynames(file_format='DD', trange=trange, hour_res=hres)
hh = file_dailynames(file_format='hh', trange=trange, hour_res=hres)
yyyymm = file_dailynames(file_format='YYYYMM', trange=trange, hour_res=hres)
yyyymmdd = file_dailynames(file_format='YYYYMMDD', trange=trange, hour_res=hres)
yyyymmddhh = file_dailynames(file_format='YYYYMMDDhh', trange=trange, hour_res=hres)

;===== Download files, read data, and create tplot vars at each site =====
;----- Loop -----
for isite=0, n_elements(site)-1 do begin
  for idt=0, n_elements(datatype)-1 do begin

    ;----- Set parameters for spd_download -----;
    source = file_retrieve(/struct)
    source.verbose = verbose
    source.local_data_dir  = local_data_dir
    source.remote_data_dir = remote_data_dir
    if keyword_set(no_download) then source.no_download = 1
    if keyword_set(downloadonly) then source.downloadonly = 1

    ;----- Make relpathnames -----;
    replace_strings, pathname_base, 'SITE', site[isite], pathnames
    replace_strings, pathnames, 'DATATYPE', datatype[idt], pathnames
    replace_strings, pathnames, 'YYYYMMDDhh', yyyymmddhh, pathnames
    replace_strings, pathnames, 'YYYYMMDD', yyyymmdd, pathnames
    replace_strings, pathnames, 'YYYYMM', yyyymm, pathnames
    replace_strings, pathnames, 'YYYY', yyyy, pathnames
    replace_strings, pathnames, 'yy', yy, pathnames
    replace_strings, pathnames, 'MM', mm, pathnames
    replace_strings, pathnames, 'DD', dd, pathnames
    replace_strings, pathnames, 'hh', hh, pathnames
    replace_strings, filename_base, 'SITE', site[isite], filenames
    replace_strings, filenames, 'DATATYPE', datatype[idt], filenames
    replace_strings, filenames, 'YYYYMMDDhh', yyyymmddhh, filenames
    replace_strings, filenames, 'YYYYMMDD', yyyymmdd, filenames
    replace_strings, filenames, 'YYYYMM', yyyymm, filenames
    replace_strings, filenames, 'YYYY', yyyy, filenames
    replace_strings, filenames, 'yy', yy, filenames
    replace_strings, filenames, 'MM', mm, filenames
    replace_strings, filenames, 'DD', dd, filenames
    replace_strings, filenames, 'hh', hh, filenames
    relpathnames = pathnames + filenames
	
    ;----- Download data files -----;
    files = spd_download(remote_file=relpathnames, $
                remote_path=source.remote_data_dir, $
                local_path=source.local_data_dir, $
                no_server=no_server, $
                no_download=no_download, $
                _extra=source, /last_version)

    filestest=file_test(files)
    if total(filestest) ge 1 then begin
        files=files(where(filestest eq 1))
    endif

    ;----- Load data into tplot variables -----;
    if(downloadonly eq 0) then begin
        ;*************************************************;
        ;***** Step2: Load data into tplot variables *****;
        ;*************************************************;
        case file_format of 
          'cdf': begin
            ;----- For CDF format files -----;
            prefix='test_'+site[isite]+'_'+datatype[idt]+'_'
;            suffix='_'+site[isite]+'_'+datatype[idt]
            cdf2tplot, files=files, verbose=source.verbose, $
                prefix=prefix, suffix=suffix
          end
          'ascii': begin
            ;----- For ASCII format files -----;
            format_type=2     ; 0:xy, 1:xyv_1, 2:xyv_2
            tformat='YYYY-MM-DD hh:mm:ss.fff'
;            tvar_column=[1, 2, 3, 4]
            tvarnames='rish_mu_uwnd'
            delimiter=' /:'
            data_start=1
            comment_symbol=''
;            v_column=0
            vvec=[1.998,2.145,2.293,2.441,2.589,2.736,2.884,3.032,3.179,3.327,3.475,3.623,3.77,3.918,4.066,4.213,4.361,4.509,4.657,4.804,4.952,5.1,5.248,5.395,5.543,5.691,5.838,5.986,6.134,6.282,6.429,6.577,6.725,6.872,7.02,7.168,7.316,7.463,7.611,7.759,7.907,8.054,8.202,8.35,8.497,8.645,8.793,8.941,9.088,9.236,9.384,9.531,9.679,9.827,9.975,10.122,10.27,10.418,10.565,10.713,10.861,11.009,11.156,11.304,11.452,11.6,11.747,11.895,12.043,12.19,12.338,12.486,12.634,12.781,12.929,13.077,13.224,13.372,13.52,13.668,13.815,13.963,14.111,14.259,14.406,14.554,14.702,14.849,14.997,15.145,15.293,15.44,15.588,15.736,15.883,16.031,16.179,16.327,16.474,16.622,16.77,16.917,17.065,17.213,17.361,17.508,17.656,17.804,17.952,18.099,18.247,18.395,18.542,18.69,18.838,18.986,19.133,19.281,19.429,19.576]
            time_column=[1,1,1,1,1,0]
            input_time=[0,0,0,0,0,0]
            ascii2tplot, files, files=files2, format_type=format_type, $
                tformat=tformat, tvar_column=tvar_column, $
                tvarnames=tvarnames, delimiter=delimiter, $
                data_start=data_start, comment_symbol=comment_symbol, $
                v_column=v_column, vvec=vvec, $
                time_column=time_column, input_time=input_time
          end
          else: begin
            print, 'Not support the file format: '+file_format
            return
          end
        endcase

        ;**********************************************;
        ;***** Step3: Options for tplot variables *****;
        ;**********************************************;
        ;----- Missing data --> NaN -----;
        tclip, tvarnames, -999, 998, /overwrite

        ;----- Ylim -----;
        ylim, tvarnames, 0, 20
        zlim, tvarnames, -100, 100

        ;----- Labels -----;
;        options, /def, tvarnames, labels=['ch1','ch2','ch3'], $
;            ytitle = 'Tatejiku', $
;            ysubtitle = '[Unit]', labflag=1, colors=[2,4,6]
    endif
  endfor
endfor

;----- Display data policy -----;
print_str_maxlet, acknowledgement

end
